@@ -69,9 +69,11 @@ class OpenStackProvider(provider.ProviderFactory):
 
     Sample configuration:
 
+    .. code-block:: json
+
         {
             "type": "OpenStackProvider",
-            "amount": 42
+            "amount": 42,
             "user": "admin",
             "tenant": "admin",
             "password": "secret",
@@ -82,7 +84,7 @@ class OpenStackProvider(provider.ProviderFactory):
                 "url": "http://example.com/disk1.img",
                 "name": "Ubuntu Precise(added by rally)",
                 "format": "qcow2",
-                "userdata": "#cloud-config\r\n disable_root: false"
+                "userdata": "disable_root: false"
             },
             "secgroup_name": "Rally"
         }
@@ -155,7 +157,7 @@ class OpenStackProvider(provider.ProviderFactory):
     def get_image_uuid(self):
         """Get image uuid. Download image if necessary."""
 
-        image_uuid = self.config["image"].get("uuid", None)
+        image_uuid = self.config["image"].get("uuid")
         if image_uuid:
             return image_uuid
         else:
@@ -187,7 +189,7 @@ class OpenStackProvider(provider.ProviderFactory):
         return image.id
 
     def get_userdata(self):
-        userdata = self.config["image"].get("userdata", None)
+        userdata = self.config["image"].get("userdata")
         return userdata
 
     def create_keypair(self):
@@ -205,7 +207,7 @@ class OpenStackProvider(provider.ProviderFactory):
         return keypair, public_key_path
 
     def get_nics(self):
-        return self.config.get("nics", None)
+        return self.config.get("nics")
 
     def create_security_group_and_rules(self):
         sec_group_name = self.config.get("secgroup_name",
