@@ -17,7 +17,7 @@ from rally.common.i18n import _
 from rally.common import logging
 from rally.common import utils as rutils
 from rally import consts
-from rally.plugins.openstack.context.cleanup import manager as resource_manager
+from rally.plugins.openstack.cleanup import manager as resource_manager
 from rally.plugins.openstack.scenarios.heat import utils as heat_utils
 from rally.task import context
 
