@@ -148,7 +148,8 @@ class HeatScenario(scenario.OpenStackScenario):
         stack = utils.wait_for(
             stack,
             ready_statuses=["CREATE_COMPLETE"],
-            update_resource=utils.get_from_manager(["CREATE_FAILED"]),
+            failure_statuses=["CREATE_FAILED"],
+            update_resource=utils.get_from_manager(),
             timeout=CONF.benchmark.heat_stack_create_timeout,
             check_interval=CONF.benchmark.heat_stack_create_poll_interval)
 
@@ -182,7 +183,8 @@ class HeatScenario(scenario.OpenStackScenario):
         stack = utils.wait_for(
             stack,
             ready_statuses=["UPDATE_COMPLETE"],
-            update_resource=utils.get_from_manager(["UPDATE_FAILED"]),
+            failure_statuses=["UPDATE_FAILED"],
+            update_resource=utils.get_from_manager(),
             timeout=CONF.benchmark.heat_stack_update_timeout,
             check_interval=CONF.benchmark.heat_stack_update_poll_interval)
         return stack
@@ -199,6 +201,7 @@ class HeatScenario(scenario.OpenStackScenario):
         utils.wait_for(
             stack,
             ready_statuses=["CHECK_COMPLETE"],
+            failure_statuses=["CHECK_FAILED"],
             update_resource=utils.get_from_manager(["CHECK_FAILED"]),
             timeout=CONF.benchmark.heat_stack_check_timeout,
             check_interval=CONF.benchmark.heat_stack_check_poll_interval)
@@ -214,7 +217,8 @@ class HeatScenario(scenario.OpenStackScenario):
         stack.delete()
         utils.wait_for_status(
             stack,
-            ready_statuses=["deleted"],
+            ready_statuses=["DELETE_COMPLETE"],
+            failure_statuses=["DELETE_FAILED"],
             check_deletion=True,
             update_resource=utils.get_from_manager(),
             timeout=CONF.benchmark.heat_stack_delete_timeout,
@@ -231,8 +235,8 @@ class HeatScenario(scenario.OpenStackScenario):
         utils.wait_for(
             stack,
             ready_statuses=["SUSPEND_COMPLETE"],
-            update_resource=utils.get_from_manager(
-                ["SUSPEND_FAILED"]),
+            failure_statuses=["SUSPEND_FAILED"],
+            update_resource=utils.get_from_manager(),
             timeout=CONF.benchmark.heat_stack_suspend_timeout,
             check_interval=CONF.benchmark.heat_stack_suspend_poll_interval)
 
@@ -247,8 +251,8 @@ class HeatScenario(scenario.OpenStackScenario):
         utils.wait_for(
             stack,
             ready_statuses=["RESUME_COMPLETE"],
-            update_resource=utils.get_from_manager(
-                ["RESUME_FAILED"]),
+            failure_statuses=["RESUME_FAILED"],
+            update_resource=utils.get_from_manager(),
             timeout=CONF.benchmark.heat_stack_resume_timeout,
             check_interval=CONF.benchmark.heat_stack_resume_poll_interval)
 
@@ -264,8 +268,8 @@ class HeatScenario(scenario.OpenStackScenario):
         utils.wait_for(
             stack,
             ready_statuses=["SNAPSHOT_COMPLETE"],
-            update_resource=utils.get_from_manager(
-                ["SNAPSHOT_FAILED"]),
+            failure_statuses=["SNAPSHOT_FAILED"],
+            update_resource=utils.get_from_manager(),
             timeout=CONF.benchmark.heat_stack_snapshot_timeout,
             check_interval=CONF.benchmark.heat_stack_snapshot_poll_interval)
         return snapshot
@@ -281,8 +285,8 @@ class HeatScenario(scenario.OpenStackScenario):
         utils.wait_for(
             stack,
             ready_statuses=["RESTORE_COMPLETE"],
-            update_resource=utils.get_from_manager(
-                ["RESTORE_FAILED"]),
+            failure_statuses=["RESTORE_FAILED"],
+            update_resource=utils.get_from_manager(),
             timeout=CONF.benchmark.heat_stack_restore_timeout,
             check_interval=CONF.benchmark.heat_stack_restore_poll_interval
         )
@@ -319,8 +323,8 @@ class HeatScenario(scenario.OpenStackScenario):
                 stack,
                 is_ready=lambda s: (
                     self._count_instances(s) == expected_instances),
-                update_resource=utils.get_from_manager(
-                    ["UPDATE_FAILED"]),
+                failure_statuses=["UPDATE_FAILED"],
+                update_resource=utils.get_from_manager(),
                 timeout=CONF.benchmark.heat_stack_scale_timeout,
                 check_interval=CONF.benchmark.heat_stack_scale_poll_interval)
 
