@@ -13,8 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import random
+
 from rally.common.i18n import _
-from rally.common import log as logging
+from rally.common import logging
 from rally import exceptions
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.wrappers import network as network_wrapper
@@ -26,13 +28,15 @@ LOG = logging.getLogger(__name__)
 class NeutronScenario(scenario.OpenStackScenario):
     """Base class for Neutron scenarios with basic atomic actions."""
 
-    RESOURCE_NAME_PREFIX = "rally_net_"
-    RESOURCE_NAME_LENGTH = 16
     SUBNET_IP_VERSION = 4
     # TODO(rkiran): modify in case LBaaS-v2 requires
     LB_METHOD = "ROUND_ROBIN"
     LB_PROTOCOL = "HTTP"
     LB_PROTOCOL_PORT = 80
+    HM_TYPE = "PING"
+    HM_MAX_RETRIES = 3
+    HM_DELAY = 20
+    HM_TIMEOUT = 10
 
     def _warn_about_deprecated_name_kwarg(self, resource, kwargs):
         """Warn about use of a deprecated 'name' kwarg and replace it.
@@ -49,7 +53,7 @@ class NeutronScenario(scenario.OpenStackScenario):
 
         :param resource: A neutron resource object dict describing the
                          resource that the name is being set for. In
-                         particular, this must have have a single key
+                         particular, this must have a single key
                          that is the resource type, and a single value
                          that is itself a dict including the "id" key.
         :param kwargs: The keyword arg dict that the user supplied,
@@ -57,7 +61,7 @@ class NeutronScenario(scenario.OpenStackScenario):
         :returns: None; kwargs is modified in situ.
         """
         if "name" in kwargs:
-            kwargs["name"] = self._generate_random_name()
+            kwargs["name"] = self.generate_random_name()
             LOG.warning(_("Cannot set name of %(type)s %(id)s explicitly; "
                           "setting to random string %(name)s") %
                         {"type": list(resource.keys())[0],
@@ -85,20 +89,19 @@ class NeutronScenario(scenario.OpenStackScenario):
         :param network_create_args: dict, POST /v2.0/networks request options
         :returns: neutron network dict
         """
-        network_create_args.setdefault("name", self._generate_random_name())
+        network_create_args["name"] = self.generate_random_name()
         return self.clients("neutron").create_network(
             {"network": network_create_args})
 
-    def _list_networks(self, atomic_action=True, **kwargs):
+    @atomic.optional_action_timer("neutron.list_networks")
+    def _list_networks(self, **kwargs):
         """Return user networks list.
 
-        :param atomic_action: True if this is an atomic action
+        :param atomic_action: True if this is an atomic action. added
+                              and handled by the
+                              optional_action_timer() decorator
         :param kwargs: network list options
         """
-        if atomic_action:
-            with atomic.ActionTimer(self, "neutron.list_networks"):
-                return self.clients("neutron").list_networks(
-                    **kwargs)["networks"]
         return self.clients("neutron").list_networks(**kwargs)["networks"]
 
     @atomic.action_timer("neutron.update_network")
@@ -140,8 +143,7 @@ class NeutronScenario(scenario.OpenStackScenario):
                 network_wrapper.generate_cidr(start_cidr=start_cidr))
 
         subnet_create_args["network_id"] = network_id
-        subnet_create_args.setdefault(
-            "name", self._generate_random_name("rally_subnet_"))
+        subnet_create_args["name"] = self.generate_random_name()
         subnet_create_args.setdefault("ip_version", self.SUBNET_IP_VERSION)
 
         return self.clients("neutron").create_subnet(
@@ -182,8 +184,7 @@ class NeutronScenario(scenario.OpenStackScenario):
         :param router_create_args: POST /v2.0/routers request options
         :returns: neutron router dict
         """
-        router_create_args.setdefault(
-            "name", self._generate_random_name("rally_router_"))
+        router_create_args["name"] = self.generate_random_name()
 
         if external_gw:
             for network in self._list_networks():
@@ -234,8 +235,7 @@ class NeutronScenario(scenario.OpenStackScenario):
         :returns: neutron port dict
         """
         port_create_args["network_id"] = network["network"]["id"]
-        port_create_args.setdefault(
-            "name", self._generate_random_name("rally_port_"))
+        port_create_args["name"] = self.generate_random_name()
         return self.clients("neutron").create_port({"port": port_create_args})
 
     @atomic.action_timer("neutron.list_ports")
@@ -265,6 +265,47 @@ class NeutronScenario(scenario.OpenStackScenario):
         """
         self.clients("neutron").delete_port(port["port"]["id"])
 
+    @logging.log_deprecated_args(_("network_create_args is deprecated; "
+                                   "use the network context instead"),
+                                 "0.1.0", "network_create_args")
+    def _get_or_create_network(self, network_create_args=None):
+        """Get a network from context, or create a new one.
+
+        This lets users either create networks with the 'network'
+        context, provide existing networks with the 'existing_network'
+        context, or let the scenario create a default network for
+        them. Running this without one of the network contexts is
+        deprecated.
+
+        :param network_create_args: Deprecated way to provide network
+                                    creation args; use the network
+                                    context instead.
+        :returns: Network dict
+        """
+        if "networks" in self.context["tenant"]:
+            return {"network":
+                    random.choice(self.context["tenant"]["networks"])}
+        else:
+            LOG.warning(_("Running this scenario without either the 'network' "
+                          "or 'existing_network' context is deprecated"))
+            return self._create_network(network_create_args or {})
+
+    def _create_subnets(self, network,
+                        subnet_create_args=None,
+                        subnet_cidr_start=None,
+                        subnets_per_network=1):
+        """Create <count> new subnets in the given network.
+
+        :param network: network to create subnets in
+        :param subnet_create_args: dict, POST /v2.0/subnets request options
+        :param subnet_cidr_start: str, start value for subnets CIDR
+        :param subnets_per_network: int, number of subnets for one network
+        :returns: List of subnet dicts
+        """
+        return [self._create_subnet(network, subnet_create_args or {},
+                                    subnet_cidr_start)
+                for i in range(subnets_per_network)]
+
     def _create_network_and_subnets(self,
                                     network_create_args=None,
                                     subnet_create_args=None,
@@ -278,15 +319,39 @@ class NeutronScenario(scenario.OpenStackScenario):
         :parm subnet_cidr_start: str, start value for subnets CIDR
         :returns: tuple of result network and subnets list
         """
-        subnets = []
         network = self._create_network(network_create_args or {})
-
-        for i in range(subnets_per_network):
-            subnet = self._create_subnet(network, subnet_create_args or {},
-                                         subnet_cidr_start)
-            subnets.append(subnet)
+        subnets = self._create_subnets(network, subnet_create_args,
+                                       subnet_cidr_start, subnets_per_network)
         return network, subnets
 
+    def _create_network_structure(self, network_create_args=None,
+                                  subnet_create_args=None,
+                                  subnet_cidr_start=None,
+                                  subnets_per_network=None,
+                                  router_create_args=None):
+        """Create a network and a given number of subnets and routers.
+
+        :param network_create_args: dict, POST /v2.0/networks request options
+        :param subnet_create_args: dict, POST /v2.0/subnets request options
+        :param subnet_cidr_start: str, start value for subnets CIDR
+        :param subnets_per_network: int, number of subnets for one network
+        :param router_create_args: dict, POST /v2.0/routers request options
+        :returns: tuple of (network, subnets, routers)
+        """
+        network = self._get_or_create_network(network_create_args)
+        subnets = self._create_subnets(network, subnet_create_args,
+                                       subnet_cidr_start,
+                                       subnets_per_network)
+
+        routers = []
+        for subnet in subnets:
+            router = self._create_router(router_create_args or {})
+            self._add_interface_router(subnet["subnet"],
+                                       router["router"])
+            routers.append(router)
+
+        return (network, subnets, routers)
+
     @atomic.action_timer("neutron.add_interface_router")
     def _add_interface_router(self, subnet, router):
         """Connect subnet to router.
@@ -307,23 +372,22 @@ class NeutronScenario(scenario.OpenStackScenario):
         self.clients("neutron").remove_interface_router(
             router["id"], {"subnet_id": subnet["id"]})
 
-    def _create_lb_pool(self, subnet_id, atomic_action=True,
-                        **pool_create_args):
+    @atomic.optional_action_timer("neutron.create_pool")
+    def _create_lb_pool(self, subnet_id, **pool_create_args):
         """Create LB pool(v1)
 
         :param subnet_id: str, neutron subnet-id
         :param pool_create_args: dict, POST /lb/pools request options
-        :param atomic_action: True if this is an atomic action
+        :param atomic_action: True if this is an atomic action. added
+                              and handled by the
+                              optional_action_timer() decorator
         :returns: dict, neutron lb pool
         """
         args = {"lb_method": self.LB_METHOD,
                 "protocol": self.LB_PROTOCOL,
-                "name": self._generate_random_name("rally_pool_"),
+                "name": self.generate_random_name(),
                 "subnet_id": subnet_id}
         args.update(pool_create_args)
-        if atomic_action:
-            with atomic.ActionTimer(self, "neutron.create_pool"):
-                return self.clients("neutron").create_pool({"pool": args})
         return self.clients("neutron").create_pool({"pool": args})
 
     def _create_v1_pools(self, networks, **pool_create_args):
@@ -380,7 +444,7 @@ class NeutronScenario(scenario.OpenStackScenario):
         """
         args = {"protocol": self.LB_PROTOCOL,
                 "protocol_port": self.LB_PROTOCOL_PORT,
-                "name": self._generate_random_name("rally_vip_"),
+                "name": self.generate_random_name(),
                 "pool_id": pool["pool"]["id"],
                 "subnet_id": pool["pool"]["subnet_id"]}
         args.update(vip_create_args)
@@ -439,3 +503,99 @@ class NeutronScenario(scenario.OpenStackScenario):
         :param: dict, floating IP object
         """
         return self.clients("neutron").delete_floatingip(floating_ip["id"])
+
+    @atomic.optional_action_timer("neutron.create_healthmonitor")
+    def _create_v1_healthmonitor(self, **healthmonitor_create_args):
+        """Create LB healthmonitor.
+
+        This atomic function creates healthmonitor with the provided
+        healthmonitor_create_args.
+
+        :param atomic_action: True if this is an atomic action. added
+                              and handled by the
+                              optional_action_timer() decorator
+        :param healthmonitor_create_args: dict, POST /lb/healthmonitors
+        :returns: neutron healthmonitor dict
+        """
+        args = {"type": self.HM_TYPE,
+                "delay": self.HM_DELAY,
+                "max_retries": self.HM_MAX_RETRIES,
+                "timeout": self.HM_TIMEOUT}
+        args.update(healthmonitor_create_args)
+        return self.clients("neutron").create_health_monitor(
+            {"health_monitor": args})
+
+    @atomic.action_timer("neutron.list_healthmonitors")
+    def _list_v1_healthmonitors(self, **kwargs):
+        """List LB healthmonitors.
+
+        This atomic function lists all helthmonitors.
+
+        :param kwargs: optional parameters
+        :returns: neutron lb healthmonitor list
+        """
+        return self.clients("neutron").list_health_monitors(**kwargs)
+
+    @atomic.action_timer("neutron.delete_healthmonitor")
+    def _delete_v1_healthmonitor(self, healthmonitor):
+        """Delete neutron healthmonitor.
+
+        :param healthmonitor: neutron healthmonitor dict
+        """
+        self.clients("neutron").delete_health_monitor(healthmonitor["id"])
+
+    @atomic.action_timer("neutron.update_healthmonitor")
+    def _update_v1_healthmonitor(self, healthmonitor,
+                                 **healthmonitor_update_args):
+        """Update neutron healthmonitor.
+
+        :param healthmonitor: neutron lb healthmonitor dict
+        :param healthmonitor_update_args: POST /lb/healthmonitors
+        update options
+        :returns: updated neutron lb healthmonitor dict
+        """
+        body = {"health_monitor": healthmonitor_update_args}
+        return self.clients("neutron").update_health_monitor(
+            healthmonitor["health_monitor"]["id"], body)
+
+    @atomic.action_timer("neutron.create_security_group")
+    def _create_security_group(self, **security_group_create_args):
+        """Create Neutron security-group.
+
+        param: security_group_create_args: dict, POST /v2.0/security-groups
+                                          request options
+        return: dict, neutron security-group
+        """
+        security_group_create_args["name"] = self.generate_random_name()
+        return self.clients("neutron").create_security_group(
+            {"security_group": security_group_create_args})
+
+    @atomic.action_timer("neutron.delete_security_group")
+    def _delete_security_group(self, security_group):
+        """Delete Neutron security group.
+
+        param: security_group: dict, neutron security_group
+        """
+        return self.clients("neutron").delete_security_group(
+            security_group["security_group"]["id"])
+
+    @atomic.action_timer("neutron.list_security_groups")
+    def _list_security_groups(self, **kwargs):
+        """Return list of Neutron security groups."""
+        return self.clients("neutron").list_security_groups(**kwargs)
+
+    @atomic.action_timer("neutron.update_security_group")
+    def _update_security_group(self, security_group,
+                               **security_group_update_args):
+        """Update Neutron security-group.
+
+        param: security_group: dict, neutron security_group
+        param: security_group_update_args: dict, POST /v2.0/security-groups
+                                           update options
+        return: dict, updated neutron security-group
+        """
+        self._warn_about_deprecated_name_kwarg(security_group,
+                                               security_group_update_args)
+        body = {"security_group": security_group_update_args}
+        return self.clients("neutron").update_security_group(
+            security_group["security_group"]["id"], body)
